/*-------------------------------------------------------------------
 MODULE DESCRIPTION:
 This code module contains the functions to handle user input
 from the web interface. 
-------------------------------------------------------------------*/
#include "predef.h"
#include <stdio.h>
#include <stdlib.h>
#include <startnet.h>
#include <iosys.h>
#include <utils.h>
#include <ip.h>
#include <tcp.h>
#include <htmlfiles.h>
#include <http.h>
#include <string.h>
#include <basictypes.h>
#include <serial.h>
#include "urlweb.h"


//----- global vars -----
const char FirmwareVersion[] = "1.0, 1/29/2003";

#define MAX_BUTTONS 2
const char LinkName[MAX_BUTTONS][80] = {
	"RELAY ON",
	"RELAY OFF"
};



/*-------------------------------------------------------------------
 This function displays the buttons and creates links so that the
 selection of a button will send information to the GET handler
 and the appropriate action can then be performed. The button selection
 information will be sent in the URL.
 ------------------------------------------------------------------*/
void DisplayButtons(int sock, PCSTR url)
{
	iprintf("DisplayButtons url: %s\r\n", url);

	// The URL will look like index.htm?number. The following code
	// will verify the '?' exists, then get the button number and
	// convert it to an integer.
	int  ButtonNum;
	char *pos = NULL;
	if ( (pos = strchr(url, '?')) != NULL )
	{
		ButtonNum = atoi((char *)(pos+1)); 
		if ( (ButtonNum < 0) || (ButtonNum > MAX_BUTTONS) )
			ButtonNum = -1;
	}
	else
		ButtonNum = -1;

	// Now step through each button number and write the HTML table element
	for (int i = 0; i < MAX_BUTTONS; i++)
	{
		char buffer[160];

		if (ButtonNum == i)
		{

			/* The output row format is: 
			   <td><A href="index.htm?#"><img src="btnOn.gif"></A></td>
			   where '#' is the value of the URL representing a link to
			   the button number and command to send. 
			*/
		   	siprintf(buffer,
		   	"<tr><td><A href=\"index.htm?%d\" ><img src=\"btnOn.gif\"> %s </a></td></tr>",i,LinkName[i]);
		}
		else
		{
			/* The output row format is: 
			   <td><A href="index.htm?#"><img src="btnOff.gif"></A></td>
			   where '#' is the value of the URL representing a link to
			   the button number and command to send. 
			*/
			siprintf(buffer,
			"<tr><td><A href=\"index.htm?%d\" ><img src=\"btnOff.gif\"> %s </a></td></tr>",i,LinkName[i]);
		}
		writestring(sock,buffer);
	}

}



static http_gethandler  * oldhand;
/*-------------------------------------------------------------------
 Override GET requests to the web server
 Parameters:
 	sock  	= Handle to open socket connection from client
	url   	= URL client used to get here
	rxBuffer = Pointer to the complete HTTP request
 ------------------------------------------------------------------*/
int MyDoGet(int sock, PSTR url, PSTR rxBuffer)
{
	iprintf("MyDoGet() URL: %s\r\n", url);

	if (strlen(url))
	{
		// The URL will look like index.htm?number. The following code
		// will verify the '?' exists, then get the button number and
		// convert it to an integer.
		int  ButtonNum;
		char *pos = NULL;
		if ( (pos = strchr(url, '?')) != NULL )
		{
			ButtonNum = atoi((char *)(pos+1)); 
			if ( (ButtonNum < 0) || (ButtonNum > MAX_BUTTONS) )
				ButtonNum = -1;

			switch (ButtonNum)
			{
				case 0: iprintf("Selected Button 0\r\n");
						break;

				case 1: iprintf("Selected Button 1\r\n");
						break;
			}
		}
		else
			ButtonNum = -1;
	}

	return (* oldhand)(sock, url, rxBuffer);
}



/*-------------------------------------------------------------------
 Register new post and get handlers and initialize plot functions
 ------------------------------------------------------------------*/
void RegisterGet()
{
	oldhand = SetNewGetHandler(MyDoGet);
}

